#
# spec file for package java-atk-wrapper
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global major_version 0.40
Name:           java-atk-wrapper
Version:        %{major_version}.0
Release:        1.3
Summary:        Java ATK Wrapper
License:        LGPL-2.0-or-later
Group:          Development/Libraries/Java
URL:            https://gitlab.gnome.org/GNOME/java-atk-wrapper/
Source0:        https://download.gnome.org/sources/%{name}/%{major_version}/%{name}-%{version}.tar.xz
Source1:        HOWTO
Source2:        https://gitlab.gnome.org/GNOME/%{name}/-/raw/%{version}/autogen.sh
Patch0:         jaw-dependencies.patch
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  java-devel >= 9
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  xprop
BuildRequires:  xz
BuildRequires:  pkgconfig(atk) >= 2.14.0
BuildRequires:  pkgconfig(atk-bridge-2.0) >= 2.33.1
BuildRequires:  pkgconfig(atspi-2) >= 2.14.0
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gdk-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gthread-2.0)
Requires:       java >= 1.8
Requires:       xprop

%description
Java ATK Wrapper is a implementation of ATK by using JNI technic. It
converts Java Swing events into ATK events, and send these events to
ATK-Bridge.

JAW is part of the Bonobo deprecation project. It will replaces the
former java-access-bridge.
By talking to ATK-Bridge, it keeps itself from being affected by the
change of underlying communication mechanism.

%prep
%setup -q
%patch -P 0 -p1
cp %{SOURCE1} %{SOURCE2} .

%build
chmod +x autogen.sh
./autogen.sh
%configure --libdir=%{_libdir}/%{name} --enable-modular-jar
make %{?_smp_mflags}

%install
make -C jni install DESTDIR=%{buildroot}
install wrapper/java-atk-wrapper.jar %{buildroot}%{_libdir}/%{name}/
find %{buildroot} -type f -name "*.la" -delete -print

%files
%doc AUTHORS
%license COPYING.LESSER
%doc NEWS
%doc README
%doc HOWTO
%{_libdir}/%{name}/

%changelog
* Tue Feb 20 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
  * Wrapper:
    + Make collapsed java state mapped to ATK_STATE_COLLAPSED
    + Also use dbus to detect accessibility being enabled
* Fri Feb 17 2023 Fridrich Strba <fstrba@suse.com>
- Update to 0.40.0
* Mon Mar  7 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * jaw-dependencies.patch
    + Compile all java files in one run
    + Compile the classes with source/target 8, since the code
    does not allow lower versions
    + Compile the module-info.class with source/target 9
* Fri Dec 11 2020 Fridrich Strba <fstrba@suse.com>
- Do not build as modular jar, since it is only used by Java 8
- Force building with Java 8 in order to avoid incompatible classes
  merged into our different modular Javas.
* Mon Nov  9 2020 Fridrich Strba <fstrba@suse.com>
- Update to 0.38.0
  * Build:
    + Fix 32bit build
    + Distribute manifest.txt
    + 783982: Fix build warnings
    + 789956: Build cleanups
    + Allow building outside source tree
    + Do not use GTK+
    + Require java 7
    + 789959: Provide a java module
    + Bump atk-bridge-2.0 dependency to 2.33.1
    + 760227: Filter out AtkWrapper.java from distributed files
    + 768824: Replace GNOME_COMPILE_WARNINGS with AX_COMPILER_FLAGS
    + Fix all warnings
    + Extend JAW_DEBUG
    + 752590: Include --enable-compile-warning option
    + 752350: Make with PLATFORM_CFLAGS
    + 752095: Remove AC_PROG_RANLIB and AC_ISC_POSIX from configure.ac
    + 750533: Don't use hard path for HOME install
  * JNI:
    + 752588: Create AtkWrapper.h and include in AtkWrapper.c
    + 751997: Create prototype for access init and shutdown
    + 740439: Create jaw_editable_text_set_run_attributes
    + 752334: remove jaw_table_get_index_at
    + 740542: Create jaw_action_get_localized_name
    + 752291: Replace jaw_set_current_value with jaw_value_set_value
    + 742499: Implement bounds-changed signal in AtkWrapper
    + 752236: Create jaw_value_get_range
    + 752190: Create jaw_table_cell_get_column_span
    + 752188: Create jaw_table_cell_get_row_span
    + 752187: Create jaw_table_cell_get_row_column_span
    + 752174: Create jaw_table_cell_get_position
    + 751267:  BUGFIX: remove custom implementation of util listeners
    + 752346: Fix unused event listener warnings in jaw_util
  * Wrapper:
    + Fix extents value for invalid extents
    + Compact data-changed events queue
    + Provide javax.accessibility.AccessibilityProvider
    + 754688, 768347: Fix crashes on accessible context being NULL
    + 775609: Fix crashes on accessiblestateset being NULL
    + 793544: Fix crashes on ref_selection returning NULL
    + 760058: Deliver accessibility events in a separate context
    + 766772: Fix crash on unbound recursion
    + 770575: Gracefully abort initialization if at-spi fails
    + 793620: Fix iterating hash table in jaw_impl_finalize
    + 793823: Fix coordinates returned by atkcomponent
    + 791970: Fix removing component listener
    + 766774: Call jaw_impl_get_instance from the application thread
    + 793543: Make sure atk objects exist while processing signals
    + 793622: Fix missing reference addition on children_changed::add
    + 793821: Fix atk event parameters
    + 775947: Make jaw thread a daemon thread
    + 793819: Fix freeing objects
    + 669029: Fix netbeans crashes
    + 754748: Fix freemind crashes
    + 758242: Fix swing threading rules
    + Fix SetName/Description/Role/AccessibleParent
    + Fix GetLocale
    + Fix Component extents
    + Fix TableSetCaption/Summary
    + Fix ActionSet/GetDescription
    + Fix GetTextAtOffset
    + Add GetTextBefore/AfterOffset
    + Fix calling Accessible* methods in the EDT only
    + Fix weak/global reference management, to make sure Accessible objects can
    + easily be freed by the GC, but Atk* objects can't.
    + Fix some null dereferences
    + Fix text selection offsets
    + Support alt graph modifier
    + Fix key event hw_code reporting
    + Support TableGetIndexAt
    + Fix TableCell
    + 750937: Emit object:visible-data-changed signals
    + 752319: Create java AtkTextGranularity interface
    + 740439: Create setRunAttributes in AtkEditableText
    + 740542: Create getLocalizedName in AtkAction
    + 752190: Create getColumnSpan in AtkTableCell
    + 752188: Create getRowSpan in AtkTableCell
    + 752187: Create getRowColumnSpan in AtkTableCell
    + 752174: Create getPosition for AtkTableCell
  * Internal:
    + Make debugging cope with current directory not being writable
    + Improve debugging log
    + Update HACKING
    + Update bug tracker URL
    + Update missing atk interface implementations
    + Document the whole picture
    + Make Samuel Thibault maintainer
  * Maintainership:
    + Update HACKING
- Removed patches
  * jaw-avoid-version.patch
  * jaw-gdk.patch
  * jaw-java_required.patch
  * jaw-javah.patch
  * jaw-quotes.patch
    + integrated upstream
* Tue Jan  2 2018 fstrba@suse.com
- Added patch:
  * jaw-javah.patch
    + Do not search for javah, since it is not needed during the
    build
* Wed Nov  8 2017 fstrba@suse.com
- Added patch:
  * jaw-gdk.patch
    + Remove requirement of gdk3. It is not really needed.
* Thu Oct 26 2017 fstrba@suse.com
- Added patches:
  * jaw-quotes.patch
    + Add quotes when adding CFLAGS to JAW_CFLAGS in order to avoid
    that first of the CFLAGS be evaluated as a command
  * jaw-java_required.patch
    + Modify java requirement to 1.7, since the code cannot be
    built with source level 1.6 due to a diamond operator
- Modified patch:
  * jaw-avoid-version.patch
    + Completely discard all libtool versioning of the library
    + This library is not linked, only loaded by the java code and
    as such, it needs only .so extension
* Tue Oct 24 2017 fstrba@suse.com
- Remove the distributed AtkWrapper.java file before building,
  so that a correct version with the correct path to xprops can be
  generated during the build from AtkWrapper.java.in
* Tue Oct 10 2017 fstrba@suse.com
- Added patch:
  * jaw-avoid-version.patch
  - Avoid libtool generated symlinks for the native library,
    since it is loaded by System.loadLibrary which expects the
    library finish with .so anyway.
* Wed Sep  6 2017 fstrba@suse.com
- Upgrade to upsteam 0.33.2
- Removed patch:
  * java-atk-wrapper-fortify-decl.patch
    + Integrated upsteam
- Add manifest.txt missing from the tarball
- Force source/bytecode target to 1.7.
* Fri Oct 17 2014 fstrba@suse.com
- Upgrade to upstream 0.30.5
- Removed patch java-atk-wrapper-source-target.patch
  * No need to apply it since we can chose options for javac from
    configure line
- Force source/bytecode target to 1.5 at configure time
* Sat May  3 2014 fstrba@suse.com
- Added patch:
  * java-atk-wrapper-source-target-patch: pass options to javac to
    produce bytecode compatible with java 1.5 and higher.
- Allow to build on SLE11
  * xprop is in xorg-x11 package
* Thu Dec 12 2013 mvyskocil@suse.com
- Initial SUSE packaging of java-awt-wrapper
  * java-atk-wrapper-fortify-decl.patch to fix missing headers
